@@ -32,7 +32,6 @@
 from pathlib import PurePosixPath
 import socket
 import threading
-import time
 from typing import Union
 import webbrowser
 
@@ -163,6 +162,12 @@ class CodeChatHandler:
         print("  => (empty string)")
         return ""
 
+    # Shut down the server.
+    def shutdown_server(self) -> str:
+        print("shutdown_server")
+        shutdown_event.set()
+        return ""
+
 
 # Instantiate this class, which will be used by both servers.
 handler = CodeChatHandler()
@@ -248,6 +253,10 @@ def client_data(id: int, url_path: str) -> Union[str, Response]:
 
 # Main code
 # =========
+# When this event is ``set``, ``run_servers`` will shut down the servers and return.
+shutdown_event = threading.Event()
+
+
 # Run both servers. This does not (usually) return.
 def run_servers() -> int:
     # See if the required ports are in use, probably by another instance of this server.
@@ -269,7 +278,7 @@ def run_servers() -> int:
 
     # Taken from https://stackoverflow.com/a/45017691.
     flask_server_thread = threading.Thread(
-        target=client_app.run, name="Flask", daemon=True
+        target=client_app.run, kwargs=dict(port=HTTP_PORT), name="Flask", daemon=True
     )
     flask_server_thread.start()
 
@@ -282,7 +291,11 @@ def run_servers() -> int:
     # Run the servers in threads until a user-requested shutdown occurs.
     try:
         while True:
-            time.sleep(100)
+            # Ctrl+C is ignored while waiting, so use a 1 second poll.
+            if shutdown_event.wait(1):
+                # If the event is received, exit the loop in order to shut down. First, clear the event so the next invocation of this function will work correctly.
+                shutdown_event.clear()
+                break
     except KeyboardInterrupt:
         pass
 
